import { GeoJSON } from './geojson';
export declare function assert(condition: boolean, msg?: string): asserts condition;
/**
 * isObject
 *
 * @param {*} input variable to validate
 * @returns {boolean} true/false
 * @example
 * isObject({elevation: 10})
 * //=true
 * isObject('foo')
 * //=false
 */
export declare function isObject(input: any): input is object;
/**
 * isArray
 *
 * @param {*} input variable to validate
 * @returns {boolean} true/false
 */
export declare function isArray(input: any): input is any[];
/**
 * isNumber
 *
 * @param {*} num Number to validate
 * @returns {boolean} true/false
 * @example
 * isNumber(123)
 * //=true
 * isNumber('foo')
 * //=false
 */
export declare function isNumber(input: any): input is number;
/**
 * isString
 *
 * @param {*} input variable to validate
 * @returns {boolean} true/false
 */
export declare function isString(input: any): input is string;
/**
 * compose
 *
 * @param {function[]} functions
 * @returns {function}
 */
export declare function compose(...funcs: Function[]): (...args: any[]) => any;
/**
 * Iterate over coordinates in any GeoJSON object, similar to Array.forEach()
 * https://github.com/Turfjs/turf/blob/master/packages/turf-meta/index.mjs
 *
 * @name coordEach
 * @param {FeatureCollection|Feature|Geometry} geojson any GeoJSON object
 * @param {Function} callback a method that takes (currentCoord, coordIndex, featureIndex, multiFeatureIndex)
 * @param {boolean} [excludeWrapCoord=false] whether or not to include the final coordinate of LinearRings that wraps the ring in its iteration.
 * @returns {void}
 * @example
 * let features = featureCollection([
 *   point([26, 37], {"foo": "bar"}),
 *   point([36, 53], {"hello": "world"})
 * ]);
 *
 * coordEach(features, function (currentCoord, coordIndex, featureIndex, multiFeatureIndex, geometryIndex) {
 *   //=currentCoord
 *   //=coordIndex
 *   //=featureIndex
 *   //=multiFeatureIndex
 *   //=geometryIndex
 * });
 */
export declare function coordEach(geojson: GeoJSON, callback: Function, excludeWrapCoord?: boolean): boolean | void | never;
